@@ -9,8 +9,12 @@
 #' @return error message only
 #'
 #' @noRd
-.handle_last_command_error <- function(handle) {
-  command <- httr::GET(handle = handle, path = "/lastcommand")
+.handle_last_command_error <- function(conn) {
+  command <- httr::GET(
+    handle = conn@handle,
+    path = "/lastcommand",
+    config = httr::add_headers(.get_auth_header(conn))
+  )
 
   json_content <- httr::content(command)
   if (json_content$status == "FAILED") {
@@ -79,7 +83,7 @@
   .handle_request_error(response)
 
   if (response$status_code == 404) {
-    .handle_last_command_error(conn@handle)
+    .handle_last_command_error(conn)
   } else {
     content <- httr::content(response)
     if (is.null(content)) {
